@@ -2,8 +2,8 @@ import json
 import sys
 import requests
 from datetime import datetime
-
 import pkg_resources
+import jsonpickle
 
 from logger.src.common.configuration.httpClientConfig import HttpClientConfig
 from logger.src.common.dto.payload import Payload
@@ -76,20 +76,20 @@ with requests.Session() as session:
                     installed_packages
                 ),
                 user_info
-            ).toJSON()
+            )
         ]
 
         return create_log(Payload(
             sourceFilePath,
             eventTime,
             message,
-            json.dumps(tags),
-            detail
-        ).toJSON())
+            jsonpickle.encode(tags),
+            jsonpickle.encode(detail)
+        ))
 
 
     def error(occurred_error, event_time_required=False):
-        message = json.dumps(occurred_error)
+        message = jsonpickle.encode(occurred_error)
 
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         print('installed_packages => ', installed_packages)
@@ -127,19 +127,19 @@ with requests.Session() as session:
                     installed_packages
                 ),
                 user_info
-            ).toJSON()
+            )
         ]
 
         return create_log(Payload(
             sourceFilePath,
             eventTime,
             message,
-            json.dumps(tags),
-            detail
-        ).toJSON())
+            jsonpickle.encode(tags),
+            jsonpickle.encode(detail)
+        ))
 
 
     def create_log(payload):
         response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
-                                data=payload)
+                                data=jsonpickle.encode(payload))
         return response
